@@ -278,19 +278,28 @@ class Downloader:
         return status, html, redirected_url
 
     # aiohttp异步
-    async def fetch(self, session, url, headers=None, timeout=9, binary=False, debug=None):
+    async def fetch(self, session, url, headers=None, timeout=9, binary=False, debug=None, proxy=None):
         if not headers:
             _headers = self.headers
         if headers:
             _headers = headers
         try:
-            async with session.get(url, headers=_headers, timeout=timeout) as response:
-                status = response.status
-                html = await response.read()
-                if not binary:
-                    encoding = cchardet.detect(html)['encoding']
-                    html = html.decode(encoding, errors='ignore')
-                redirected_url = str(response.url)
+            if proxy:
+                async with session.get(url, headers=_headers, timeout=timeout, proxy=self.proxyMeta) as response:
+                    status = response.status
+                    html = await response.read()
+                    if not binary:
+                        encoding = cchardet.detect(html)['encoding']
+                        html = html.decode(encoding, errors='ignore')
+                    redirected_url = str(response.url)
+            else:
+                async with session.get(url, headers=_headers, timeout=timeout) as response:
+                    status = response.status
+                    html = await response.read()
+                    if not binary:
+                        encoding = cchardet.detect(html)['encoding']
+                        html = html.decode(encoding, errors='ignore')
+                    redirected_url = str(response.url)
         except Exception as e:
             if debug:
                 traceback.print_exc()
@@ -301,19 +310,30 @@ class Downloader:
             redirected_url = url
         return status, html, redirected_url
 
-    async def post_fetch(self, session, url, data, headers=None, timeout=10, binary=False, debug=None):
+    async def post_fetch(self, session, url, data, headers=None, timeout=10, binary=False, debug=None, proxy=None):
         if not headers:
             _headers = self.headers
         if headers:
             _headers = headers
         try:
-            async with session.post(url, headers=_headers, data=data, timeout=timeout) as response:
-                status = response.status
-                html = await response.read()
-                if not binary:
-                    encoding = cchardet.detect(html)['encoding']
-                    html = html.decode(encoding, errors='ignore')
-                redirected_url = str(response.url)
+            if proxy:
+                async with session.post(url, headers=_headers, data=data, timeout=timeout,
+                                        proxy=self.proxyMeta) as response:
+                    status = response.status
+                    html = await response.read()
+                    if not binary:
+                        encoding = cchardet.detect(html)['encoding']
+                        html = html.decode(encoding, errors='ignore')
+                    redirected_url = str(response.url)
+            else:
+                async with session.post(url, headers=_headers, data=data, timeout=timeout) as response:
+                    status = response.status
+                    html = await response.read()
+                    if not binary:
+                        encoding = cchardet.detect(html)['encoding']
+                        html = html.decode(encoding, errors='ignore')
+                    redirected_url = str(response.url)
+
         except Exception as e:
             if debug:
                 traceback.print_exc()
